@@ -31,7 +31,7 @@ sub new {
 	$self->{m_staticText1}->SetFont(
 		Wx::Font->new( Wx::wxNORMAL_FONT->GetPointSize, 70, 90, 92, 0, "" )
 	);
-	$self->{m_staticText1}->SetTooltip(
+	$self->{m_staticText1}->SetToolTip(
 		Wx::gettext("Who is awesome")
 	);
 
@@ -54,7 +54,7 @@ sub new {
 		Wx::gettext("MyButton"),
 	);
 	$self->{m_button1}->SetDefault;
-	$self->{m_button1}->SetTooltip(
+	$self->{m_button1}->SetToolTip(
 		Wx::gettext("Click to do nothing")
 	);
 
